@@ -13,6 +13,7 @@ from __future__ import absolute_import, division, print_function, with_statement
 import os
 import logging
 from . import exc
+from .util import basestring
 
 logger = logging.getLogger(__name__)
 
@@ -35,7 +36,8 @@ def check_consistency(sconf):
             raise exc.ConfigError('config window is missing "window_name"')
 
         if not 'panes' in window:
-            raise exc.ConfigError('config window %s requires list of panes' % window['window_name'])
+            raise exc.ConfigError(
+                'config window %s requires list of panes' % window['window_name'])
 
     return True
 
