@@ -17,6 +17,7 @@ logger = logging.getLogger(__name__)
 
 
 class WorkspaceBuilder(object):
+
     '''
     Build tmux workspace from a configuration. Creates and names windows, sets
     options, splits windows into panes.
@@ -112,10 +113,12 @@ class WorkspaceBuilder(object):
 
             if self.server.has_session(self.sconf['session_name']):
                 raise exc.TmuxSessionExists(
-                    'Session name %s is already running.' % self.sconf['session_name']
+                    'Session name %s is already running.' % self.sconf[
+                        'session_name']
                 )
             else:
-                session = self.server.new_session(session_name=self.sconf['session_name'])
+                session = self.server.new_session(
+                    session_name=self.sconf['session_name'])
 
             assert(self.sconf['session_name'] == session.get('session_name'))
 
@@ -123,7 +126,6 @@ class WorkspaceBuilder(object):
 
         for w, wconf in self.iter_create_windows(session):
             assert(isinstance(w, Window))
-            w.list_panes()
             for p in self.iter_create_panes(w, wconf):
                 assert(isinstance(p, Pane))
                 p = p
@@ -151,7 +153,7 @@ class WorkspaceBuilder(object):
                 window_name = wconf['window_name']
 
             if i == int(1):  # if first window, use window 1
-                #w = s.select_window(1)
+                # w = s.select_window(1)
                 w = s.attached_window()
                 w = w.rename_window(window_name)
             else:
@@ -164,13 +166,13 @@ class WorkspaceBuilder(object):
             assert(isinstance(w, Window))
 
             if 'options' in wconf and isinstance(wconf['options'], dict):
-                for key, val in wconf['options'].iteritems():
+                for key, val in wconf['options'].items():
                     w.set_window_option(key, val)
 
             if 'focus' in wconf and wconf['focus']:
                 s.select_window(w['window_id'])
 
-            w.list_panes()
+            s.server._update_windows()
 
             yield w, wconf
 
@@ -196,14 +198,12 @@ class WorkspaceBuilder(object):
                 p = w.attached_pane()
                 assert(isinstance(p, Pane))
 
-            p.refresh()
-
             for cmd in pconf['shell_command']:
                 p.send_keys(cmd)
 
             if 'focus' in pconf and pconf['focus']:
                 w.select_pane(p['pane_id'])
 
-            w.list_panes()
+            w.server._update_panes()
 
             yield p
